Value

Enum Value 

pub enum Value {
Show 15 variants Null, Bool(bool), UInt8(u8), UInt16(u16), UInt32(u32), UInt64(u64), SInt8(i8), SInt16(i16), SInt32(i32), SInt64(i64), Float32(f32), Float64(f64), Binary(Vec<u8>), String(String), List(Vec<Self>),
}
The value directly returned by the server without any additional type parsing and/or casting

Variants



Null

A null value



Bool(bool)

A bool



UInt8(u8)

An u8



UInt16(u16)

An u16



UInt32(u32)

An u32



UInt64(u64)

An u64



SInt8(i8)

An i8



SInt16(i16)

An i16



SInt32(i32)

An i32



SInt64(i64)

An i64



Float32(f32)

A f32



Float64(f64)

A f64



Binary(Vec<u8>)



String(String)



List(Vec<Self>)

A nested list

Implementations

Source

impl Value

pub fn parse<T: FromValue>(self) -> ClientResult<T>

Attempt to parse this value into a different type

pub fn parse_cloned<T: FromValue>(&self) -> ClientResult<T>

Attempt to parse this value into a different type, by cloning the value first